==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiGui/QMoveEvent_shell.cpp <==
#include "QMoveEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QMoveEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QMoveEvent")
    QMoveEvent *_ptr = reinterpret_cast<QMoveEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QMoveEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QMoveEvent_shell) ); }

jmethodID QMoveEvent_shell::__shell_javaMethod(int pos) const { return QMoveEvent_shell::__shell()->javaMethod(typeid(QMoveEvent), pos); }

// emitting (writeShellConstructor)
QMoveEvent_shell::QMoveEvent_shell(const QPoint& pos0, const QPoint& oldPos1)
    : QMoveEvent(pos0, oldPos1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QMoveEvent::QMoveEvent_shell(const QPoint& pos0, const QPoint& oldPos1)", QMoveEvent_shell::__shell())
    QMoveEvent_shell::__shell()->constructed(typeid(QMoveEvent));
}

// emitting (writeShellDestructor)
QMoveEvent_shell::~QMoveEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QMoveEvent::~QMoveEvent()", QMoveEvent_shell::__shell())
    QMoveEvent_shell::__shell()->destructed(typeid(QMoveEvent));
}

void QMoveEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QMoveEvent_shell*>(ptr)->QMoveEvent_shell::__shell()->tryDeleteShell(typeid(QMoveEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QMoveEvent(QPoint,QPoint)
void __qt_construct_QMoveEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QMoveEvent(QPoint,QPoint)")
    jobject pos0 = __java_arguments[0].l;
    const QPoint& __qt_pos0 = qtjambi_cast<const QPoint& >(__jni_env, pos0);
    jobject oldPos1 = __java_arguments[1].l;
    const QPoint& __qt_oldPos1 = qtjambi_cast<const QPoint& >(__jni_env, oldPos1);
    QMoveEvent *__qt_this = new(__qtjambi_ptr) QMoveEvent_shell(__qt_pos0, __qt_oldPos1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QMoveEvent_shell
void __qt_destruct_QMoveEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QMoveEvent")
    reinterpret_cast<QMoveEvent_shell*>(ptr)->~QMoveEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QMoveEvent::QMoveEvent(QPoint,QPoint)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QMoveEvent_initialize_1native__Lio_qt_gui_QMoveEvent_2Lio_qt_core_QPoint_2Lio_qt_core_QPoint_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject pos0,
 jobject oldPos1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QMoveEvent::QMoveEvent(QPoint,QPoint)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = pos0;
        arguments[1].l = oldPos1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QMoveEvent_0, sizeof(QMoveEvent_shell), typeid(QMoveEvent), true, &deleter_QMoveEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QMoveEvent::oldPos()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QMoveEvent_oldPos_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QMoveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QMoveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMoveEvent::oldPos()const", __qt_this)
        const QPoint& __qt_return_value = __qt_this->oldPos();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QMoveEvent::pos()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QMoveEvent_pos_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QMoveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QMoveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMoveEvent::pos()const", __qt_this)
        const QPoint& __qt_return_value = __qt_this->pos();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
void QMoveEvent_access::setOldPos_cref_QPoint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID oldPos0)
{
    Q_UNUSED(__this_nativeId)
    Q_UNUSED(__jni_env)
    const QPoint& __qt_oldPos0 = QtJambiAPI::valueReferenceFromNativeId<QPoint>(oldPos0);
    this->QMoveEvent::oldp = __qt_oldPos0;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QMoveEvent_setOldPos_1native_1cref_1QPoint__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID oldPos0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QMoveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QMoveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        static_cast<QMoveEvent_access*>(__qt_this)->setOldPos_cref_QPoint(__jni_env, __this_nativeId, oldPos0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

void QMoveEvent_access::setPos_cref_QPoint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID pos0)
{
    Q_UNUSED(__this_nativeId)
    Q_UNUSED(__jni_env)
    const QPoint& __qt_pos0 = QtJambiAPI::valueReferenceFromNativeId<QPoint>(pos0);
    this->QMoveEvent::p = __qt_pos0;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QMoveEvent_setPos_1native_1cref_1QPoint__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID pos0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QMoveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QMoveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        static_cast<QMoveEvent_access*>(__qt_this)->setPos_cref_QPoint(__jni_env, __this_nativeId, pos0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QMoveEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QMoveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QMoveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QMoveEvent(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QMoveEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QMoveEvent>("QMoveEvent", "io/qt/gui/QMoveEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QMoveEvent, {
        ConstructorInfo(&__qt_construct_QMoveEvent_0, "Lio/qt/core/QPoint;Lio/qt/core/QPoint;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QMoveEvent);
    registerSizeOfShell(typeId, sizeof(QMoveEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QMoveEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QMoveEvent_shell.cpp <==
#include "QMoveEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QMoveEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QMoveEvent")
    QMoveEvent *_ptr = reinterpret_cast<QMoveEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QMoveEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QMoveEvent_shell) ); }

jmethodID QMoveEvent_shell::__shell_javaMethod(int pos) const { return QMoveEvent_shell::__shell()->javaMethod(typeid(QMoveEvent), pos); }

// emitting (writeShellConstructor)
QMoveEvent_shell::QMoveEvent_shell(const QMoveEvent& other0)
    : QMoveEvent(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QMoveEvent::QMoveEvent_shell(const QMoveEvent& other0)", QMoveEvent_shell::__shell())
    QMoveEvent_shell::__shell()->constructed(typeid(QMoveEvent));
}

QMoveEvent_shell::QMoveEvent_shell(const QPoint& pos0, const QPoint& oldPos1)
    : QMoveEvent(pos0, oldPos1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QMoveEvent::QMoveEvent_shell(const QPoint& pos0, const QPoint& oldPos1)", QMoveEvent_shell::__shell())
    QMoveEvent_shell::__shell()->constructed(typeid(QMoveEvent));
}

// emitting (writeShellDestructor)
QMoveEvent_shell::~QMoveEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QMoveEvent::~QMoveEvent()", QMoveEvent_shell::__shell())
    QMoveEvent_shell::__shell()->destructed(typeid(QMoveEvent));
}

void QMoveEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QMoveEvent_shell*>(ptr)->QMoveEvent_shell::__shell()->tryDeleteShell(typeid(QMoveEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QMoveEvent(QMoveEvent)
void __qt_construct_QMoveEvent_cref_QMoveEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QMoveEvent(QMoveEvent)")
    jobject other0 = __java_arguments[0].l;
    const QMoveEvent& __qt_other0 = qtjambi_cast<const QMoveEvent& >(__jni_env, other0);
    QMoveEvent *__qt_this = new(__qtjambi_ptr) QMoveEvent_shell(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QMoveEvent::QMoveEvent(QMoveEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QMoveEvent_initialize_1native__Lio_qt_gui_QMoveEvent_2Lio_qt_gui_QMoveEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QMoveEvent::QMoveEvent(QMoveEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QMoveEvent_cref_QMoveEvent, sizeof(QMoveEvent_shell), typeid(QMoveEvent), true, &deleter_QMoveEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QMoveEvent(QPoint,QPoint)
void __qt_construct_QMoveEvent_cref_QPoint_cref_QPoint(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QMoveEvent(QPoint,QPoint)")
    jobject pos0 = __java_arguments[0].l;
    const QPoint& __qt_pos0 = qtjambi_cast<const QPoint& >(__jni_env, pos0);
    jobject oldPos1 = __java_arguments[1].l;
    const QPoint& __qt_oldPos1 = qtjambi_cast<const QPoint& >(__jni_env, oldPos1);
    QMoveEvent *__qt_this = new(__qtjambi_ptr) QMoveEvent_shell(__qt_pos0, __qt_oldPos1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QMoveEvent::QMoveEvent(QPoint,QPoint)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QMoveEvent_initialize_1native__Lio_qt_gui_QMoveEvent_2Lio_qt_core_QPoint_2Lio_qt_core_QPoint_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject pos0,
 jobject oldPos1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QMoveEvent::QMoveEvent(QPoint,QPoint)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = pos0;
        arguments[1].l = oldPos1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QMoveEvent_cref_QPoint_cref_QPoint, sizeof(QMoveEvent_shell), typeid(QMoveEvent), true, &deleter_QMoveEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QMoveEvent_shell
void __qt_destruct_QMoveEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QMoveEvent")
    reinterpret_cast<QMoveEvent_shell*>(ptr)->~QMoveEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QMoveEvent::oldPos()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QMoveEvent_oldPos_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QMoveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QMoveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMoveEvent::oldPos()const", __qt_this)
        const QPoint& __qt_return_value = __qt_this->oldPos();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QMoveEvent::pos()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QMoveEvent_pos_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QMoveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QMoveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QMoveEvent::pos()const", __qt_this)
        const QPoint& __qt_return_value = __qt_this->pos();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
void QMoveEvent_access::setOldPos_cref_QPoint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID oldPos0)
{
    Q_UNUSED(__this_nativeId)
    Q_UNUSED(__jni_env)
    const QPoint& __qt_oldPos0 = QtJambiAPI::valueReferenceFromNativeId<QPoint>(oldPos0);
    this->QMoveEvent::oldp = __qt_oldPos0;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QMoveEvent_setOldPos_1native_1cref_1QPoint__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID oldPos0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QMoveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QMoveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        static_cast<QMoveEvent_access*>(__qt_this)->setOldPos_cref_QPoint(__jni_env, __this_nativeId, oldPos0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

void QMoveEvent_access::setPos_cref_QPoint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID pos0)
{
    Q_UNUSED(__this_nativeId)
    Q_UNUSED(__jni_env)
    const QPoint& __qt_pos0 = QtJambiAPI::valueReferenceFromNativeId<QPoint>(pos0);
    this->QMoveEvent::p = __qt_pos0;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QMoveEvent_setPos_1native_1cref_1QPoint__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID pos0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QMoveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QMoveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        static_cast<QMoveEvent_access*>(__qt_this)->setPos_cref_QPoint(__jni_env, __this_nativeId, pos0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QMoveEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QMoveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QMoveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QMoveEvent(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QMoveEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QMoveEvent>("QMoveEvent", "io/qt/gui/QMoveEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QMoveEvent, {
        ConstructorInfo(&__qt_construct_QMoveEvent_cref_QMoveEvent, "Lio/qt/gui/QMoveEvent;")
       ,ConstructorInfo(&__qt_construct_QMoveEvent_cref_QPoint_cref_QPoint, "Lio/qt/core/QPoint;Lio/qt/core/QPoint;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QMoveEvent);
    registerSizeOfShell(typeId, sizeof(QMoveEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QMoveEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
